# lambkid

lambkid is an advance lib abstract from some common use python lib. it aim to supply a more easily and more fewer code for python developer.
it will practise for life is short and I will choose python.

## install lambkid
refer to [install lambkid](https://github.com/redrose2100/lambkid/blob/master/docs/install.md)

## function of lambkid
* [sshclient](https://github.com/redrose2100/lambkid/blob/master/docs/sshclient.md)(>=0.0.6)
* [log](https://github.com/redrose2100/lambkid/blob/master/docs/log.md) (>=0.0.4)
* [cli command](https://github.com/redrose2100/lambkid/blob/master/docs/cli.md)(>=0.1.8)
